import mouse
from pynput.keyboard import Key, Controller
import keyboard
import time

out_keyboard = Controller()

def change(in_button: str, out_button: str = 'left', stop_button: str = 's'):
    while True:
        if keyboard.is_pressed(in_button) or mouse.is_pressed(in_button):
            if out_button == 'left' or out_button == 'right' or out_button == 'middle':
                time.sleep(0.06)
                mouse.click(out_button)
            else:
                time.sleep(0.06)
                out_keyboard.press(out_button)
                out_keyboard.release(out_button)
        if keyboard.is_pressed(stop_button):
            break


import os
from pynput.keyboard import Key, Controller
import time

keyboard = Controller()

if not os.path.isfile('saved-chats.txt'):
    with open('saved-chats.txt', 'w') as sv:
     sv.close()

def chat(delay: float = 0, speed: float = 0):
    data = []
    while True:
        autochat = input("What do you want to do? edit/play/view/exit ")
        if autochat == "edit" or autochat == "e":
            slot = int(input("What slot do you want to change? ")) - 1
            with open('saved-chats.txt', 'r') as sf:
                con = sf.read()
                if "," in con:
                    data = con.split(',')
            invar = input("What do you want to change it to? ")
            if slot > len(data):
                print("Please fill in the slot before first")
            else: 
                with open('saved-chats.txt', 'w') as sf:
                    if slot == len(data):
                        data.append(invar)
                    else:
                        data[slot] = invar
                    strdata = ",".join(data)
                    sf.write(strdata)
                    print("")
        if autochat == "play" or autochat == "p":
            with open('saved-chats.txt', 'r') as sf:
                con = sf.read()
                data = con.split(',')
            while True:
                slot = input("What slot do you want to play? save num/exit ")
                if not (slot == "exit" or slot == "e"):
                    slot = int(slot) - 1
                    a = data[slot]
                    b = [*a]
                    time.sleep(delay)
                    for x in range(len(b)):
                        keyboard.press(b[x])
                        keyboard.release(b[x])
                        time.sleep(speed)
                else:
                    print("")
                    time.sleep(0.1)
                    break
        if autochat == "view" or autochat == "v":
            with open('saved-chats.txt', 'r') as sf:
                con = sf.read()
                data = con.split(',')
            for x in data:
                print(x)
        if autochat == 'exit':
            print("")
            break

def spam(num: float = 10, speed: float = 1, delay: float = 0):
    if input("Use at your own risk. proceed? y/n ") == "yes" or "y":
        time.sleep(delay)
        for i in range(0,num):
            keyboard.press(Key.ctrl)
            keyboard.press('v')
            keyboard.release(Key.ctrl)
            keyboard.release('v')
            keyboard.press(Key.enter)
            keyboard.release(Key.enter)
            time.sleep(speed)

def reset():
    with open('saved-chats.txt', 'w') as sf:
        sf.write("")


import mouse
import time
from screeninfo import get_monitors
import winsound

monitor = get_monitors()[0]

ver = []
hor = []

def record(delay: float = 1, amount: float = 2):
    if amount < 1:
        raise autoPosError("one or more action required")
    for i in range(0, amount):
        time.sleep(delay)
        pos = mouse.get_position()
        ver.append(round((pos[0]/monitor.width)*100, 2))
        hor.append(round((pos[1]/monitor.height)*100, 2))
        winsound.PlaySound("beep.wav", winsound.SND_FILENAME)
    with open('pos.txt','w') as sf:
        ver_2 = [str(x) for x in ver]
        ver_2 = " ".join(ver_2)
        hor_2 = [str(x) for x in hor]
        hor_2 = " ".join(hor_2)
        store = [ver_2, hor_2]
        sf.write(",".join(store))
    
def play(speed: float = 0, delay: float = 0, movespeed: float = 0.5, button = 'none'):
    ac = 0
    with open('pos.txt','r') as sf:
        time.sleep(delay)
        output = sf.read().split(',')
        ver = output[0].split(' ')
        hor = output[1].split(' ')
        ver_2 = [float(x) for x in ver]
        hor_2 = [float(x) for x in hor]
        for x in ver:
            time.sleep(movespeed)
            mouse.move((ver_2[ac] / 100) * monitor.width, (hor_2[ac] / 100) * monitor.height, duration = speed)
            if not button == "none":
                mouse.click(button)
            ac = ac + 1
    


import mouse
import time
from pynput.keyboard import Controller

keyboard = Controller()

def click(button, speed: float = 1, duration: float = 10, delay: float = 0):
    time.sleep(delay)
    clicks = int(duration/speed)
    if button == 'left' or button == 'right' or button == 'middle':
        for i in range(0, clicks):
            mouse.click(button)
            time.sleep(speed)
    else:
        for i in range(0, clicks):
            keyboard.press(button)
            keyboard.release(button)
            time.sleep(speed)